"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

var _openHandler = _interopRequireDefault(require("./open-handler"));

var _sendHandler = _interopRequireDefault(require("./send-handler"));

var _socketInstance = _interopRequireDefault(require("./socket-instance"));

var _messageHandler = _interopRequireDefault(require("./message-handler"));

var _readyState = _interopRequireDefault(require("./ready-state"));

var _keepAlive = _interopRequireDefault(require("./keep-alive"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useMessageQueue = () => (0, _react.useRef)([]);

const useSocket = (url, {
  onMessage,
  keepAlive,
  keepAliveMaxDelay = 15000,
  socketDelay
} = {}) => {
  const [keepAliveAttempts, setKeepAliveAttempts] = (0, _react.useState)(0);
  const messageQueue = useMessageQueue();
  const socket = (0, _socketInstance.default)(url, keepAlive, keepAliveAttempts, socketDelay);
  const readyState = (0, _readyState.default)(socket);
  (0, _keepAlive.default)({
    socket,
    keepAlive,
    keepAliveMaxDelay,
    keepAliveAttempts,
    setKeepAliveAttempts
  });
  const send = (0, _sendHandler.default)({
    socket,
    messageQueue
  });
  (0, _openHandler.default)({
    messageQueue,
    send,
    socket
  });
  (0, _messageHandler.default)({
    socket,
    onMessage
  });
  return {
    readyState,
    keepAliveAttempts,
    send
  };
};

var _default = useSocket;
exports.default = _default;