"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

// need to store the socket readyState in react state so
// that we can trigger a rerender when the socket state changes
const useSocketReadyState = socket => {
  const [readyState, setReadyState] = (0, _react.useState)();
  (0, _react.useEffect)(() => {
    // when the socket first initialized, setup initial readyState
    if (socket) {
      setReadyState(socket.readyState);
    }
  }, [socket]);
  const handler = (0, _react.useCallback)(() => {
    setReadyState(socket.readyState);
  }, [socket]);
  (0, _react.useEffect)(() => {
    if (socket) {
      socket.addEventListener("open", handler);
      socket.addEventListener("error", handler);
      socket.addEventListener("close", handler);
    }

    return () => {
      if (socket) {
        socket.removeEventListener("open", handler);
        socket.removeEventListener("error", handler);
        socket.removeEventListener("close", handler);
      }
    };
  }, [socket, handler]);
  return readyState;
};

var _default = useSocketReadyState;
exports.default = _default;