"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

const useSocketAcquisition = socketDelay => {
  const socket = (0, _react.useRef)({});
  const socketsToClear = (0, _react.useRef)({});
  const [resetSignal, setResetCount] = (0, _react.useState)(0);
  const acquire = (0, _react.useCallback)((url, keepAlive, cb) => {
    delete socketsToClear.current[url];
    const t = setTimeout(() => {
      let s = socket.current[url];
      const envSupportsWebSockets = !!global.WebSocket;
      const isSocketInValidState = s && (s.readyState === WebSocket.CONNECTING || s.readyState === WebSocket.OPEN);

      if (envSupportsWebSockets && (!s || !isSocketInValidState)) {
        s = new WebSocket(url);
        socket.current[url] = s;
      }

      cb(s);
    }, socketDelay);
    return () => clearTimeout(t);
  }, [socketDelay]);
  const release = (0, _react.useCallback)(url => {
    socketsToClear.current[url] = true;
    setResetCount(c => c + 1);
  }, []);
  (0, _react.useEffect)(() => {
    let t;

    if (resetSignal > 0) {
      // cleanup socket
      t = setTimeout(() => {
        for (let url in socketsToClear.current) {
          if (socket.current[url]) {
            socket.current[url].close();
            delete socket.current[url];
          }
        }

        socketsToClear.current = {};
        t = null;
      }, socketDelay + 50);
    }

    return () => {
      if (t) {
        clearTimeout(t);
      }
    };
  }, [resetSignal, socket, socketDelay]);
  return {
    acquire,
    release
  };
};

const useSocketInstance = (url, keepAlive, keepAliveSignal, socketDelay) => {
  const [socket, setSocket] = (0, _react.useState)(null);
  const {
    acquire,
    release
  } = useSocketAcquisition(socketDelay);
  (0, _react.useEffect)(() => {
    let sock, cancelAcquire;

    if (url) {
      cancelAcquire = acquire(url, keepAlive, s => {
        sock = s;
        setSocket(s);
        cancelAcquire = null;
      });
    }

    return () => {
      if (cancelAcquire) {
        cancelAcquire();
      }

      if (sock) {
        release(url);
      }
    };
  }, [url, keepAlive, keepAliveSignal, acquire, release]);
  return socket;
};

var _default = useSocketInstance;
exports.default = _default;